@@ -16,10 +16,7 @@ def write_list_as_json_str(fields_json, rows):
                         r[field_json] = json.loads(r[field_json])
                     except TypeError:
                         continue
-    try:
-        return "\n".join([json.dumps(dict(r), default=myconverter) or "{}" for r in rows])
-    except (ValueError, TypeError):
-        return "\n".join([dict(r) or "{}" for r in rows])
+    return "\n".join([json.dumps(dict(r), default=myconverter) or "{}" for r in rows])
 
 
 def vertica_insert(cursor, target, fields, fields_json, data):
